@@ -19,5 +19,8 @@ from .withdraw import Withdraw
 from .ticker import Ticker
 from .funding_ticker import FundingTicker
 from .ledger import Ledger
+from .funding_trade import FundingTrade
+from .margin_info import MarginInfo
+from .margin_info_base import MarginInfoBase
 
-NAME = 'models'
+NAME = "models"
